#
# spec file for package o2scl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
# Python binding tests do not work in the chroot env
%bcond_with python3
%else
%bcond_with test
%bcond_without python3
%define psuffix %{nil}
%endif
%define pname o2scl
%define shlib lib%{pname}0
Name:           %{pname}%{?psuffix}
Version:        0.929.2
Release:        1.2
Summary:        Object-oriented Scientific Computing Library
License:        GPL-3.0-only
Group:          Productivity/Scientific/Math
URL:            https://awsteiner.org/code/o2scl
Source0:        https://github.com/awsteiner/o2scl/releases/download/v%{version}/%{pname}-%{version}.tar.gz
Source1:        %{pname}.rpmlintrc
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
# Required For Patch0
BuildRequires:  libtool
BuildRequires:  libboost_headers-devel >= 1.80
BuildRequires:  memory-constraints
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(armadillo)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(ncurses)
%if %{with test}
BuildRequires:  %{pname}-devel = %{version}
%endif
%if %{with python3}
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  readline-devel
%endif
Recommends:     %{pname}-doc = %{version}

%description
O2scl is a C++ library for object-oriented numerical programming. It
includes interpolation, differentiation, integration, roots of
polynomials, equation solving, minimization, constrained minimization,
Monte Carlo integration, simulated annealing, least-squares fitting,
solution of ordinary differential equations, two-dimensional
interpolation, Chebyshev approximation, unit conversions, and file I/O
with HDF5.

%package -n %{shlib}
Summary:        Shared libraries for O2scl, a scientific computation library
Group:          System/Libraries

%description -n %{shlib}
O2scl is a C++ library for object-oriented numerical programming.

This package provides the shared libraries for %{name}.

%package -n %{pname}-devel
Summary:        Source and header files for O2scl
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       armadillo-devel
Requires:       cblas-devel
Requires:       eigen3-devel
Requires:       gcc-c++
Requires:       hdf5-devel
Requires:       readline-devel
Requires:       pkgconfig(fftw3)
Requires:       pkgconfig(gsl)
Requires:       pkgconfig(mpfr)

%description -n %{pname}-devel
O2scl is a C++ library for object-oriented numerical programming.

This package provides the source and header files for writing software
using %{name}.

%package -n %{pname}-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description -n %{pname}-doc
O2scl is a C++ library for object-oriented numerical programming.
This package provides the documentation for %{name}.

%prep
%autosetup -p1 -n %{pname}-0.929
cp %{SOURCE1} doc/o2scl/
sed -Ei "s/\r$/\n/g" doc/o2scl/html/_static/evan.eml

%build
autoreconf -fvi
%limit_build -m 2500
# *_OPENSUSE_* flags disable some tolerance related tests as recommended upstream: https://github.com/awsteiner/o2scl/issues/37
export CXXFLAGS+="-DO2SCL_PLAIN_HDF5_HEADER%{?with_test: -DO2SCL_OPENSUSE -DO2SCL_OPENSUSE_I386}%{?with_python3: `numpy-config --cflags`}"
# Leap 15.X has hdf5 1.10.X
%if 0%{?suse_version} < 1650
export CXXFLAGS+=" -DO2SCL_HDF5_PRE_1_12"
%endif
# Needed to avoid "undefined symbol: GOMP_critical_name_end" when using o2sclpy from python
# https://github.com/awsteiner/o2scl/issues/40
export LDFLAGS+="-lgomp"
%configure                           \
  --enable-armadillo                 \
  --enable-eigen                     \
  --enable-fftw                      \
  --enable-openmp                    \
  --enable-ncurses                   \
  --disable-pugixml                   \
  %{?with_python3:--enable-python}   \
  %{!?with_python3:--disable-python} \
  %{nil}

%make_build

%install
%if %{without test}
%make_install
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/o2scl/* %{buildroot}%{_docdir}/%{name}/

# REMOVE BOGUS DUPLICATD DOC
rm -fr %{buildroot}%{_prefix}/search

# Remove Makefile junk
find %{buildroot}%{_docdir}/%{name}/ -name "Makefile.*" -delete -print

# Remove static libs and libtool archives
find %{buildroot}%{_libdir} "(" -name "*.a" -o -name "*.la" ")" -delete -print

%fdupes %{buildroot}%{_docdir}/%{name}/
%fdupes %{buildroot}%{_datadir}/%{name}/

%ldconfig_scriptlets -n %{shlib}

%files -n %{shlib}
%{_libdir}/*.so.*

%files -n %{pname}-devel
%doc AUTHORS ChangeLog README NEWS
%license COPYING
%{_bindir}/acol
%{_bindir}/ame_parse
%{_bindir}/yanic
%{_datadir}/%{name}/
%{_libdir}/*.so
%{_includedir}/o2scl/

%files -n %{pname}-doc
%doc %{_docdir}/%{name}/

%else

%check
%make_build check

%endif

%changelog
* Thu Sep 19 2024 Atri Bhattacharya <badshah400@gmail.com>
- Use numpy-config to fix cflags for use with numpy >= 2.0.
* Thu Jul 25 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.929.2:
  * Small fixes to address some security updates and problems on
    openSUSE and 32-bit systems.
- Enable testing on all supported archs.
* Sun Jul 14 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.929.1:
  * Small fixes to address some security updates and problems on
    32-bit systems.
* Thu May  9 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.929:
  * Created example ex_mcmc_kde.cpp.
  * Created new steppers for mcmc_para.
  * Improved Python, multiprecision, MPFR support in several
    classes.
  * Updated classes and methods inte_kronrod_boost,
    cli::xml_to_o2(), eos_leptons, eos_leptons_multip,
    inte_double_exp_boost, ode_boost, fermion_deriv_rel,
    inte_gauss_cern, inte_adapt_cern, astep_boost, boson_rel,
    calc_utf8, funct_multip, eos_sn, lib_settings, fermi_function,
    and boson_thermo.
  * Allowed for virtual environments in py_init()
  * Updates to acol commands: table rename, table3d refine, table
    cat, table3d contours, table autocorr, table thin-mcmc.
  * Updated acol function support.
  * Updated yanic.
  * Created a new O2SCL_NO_BOOST_MULTIPRECISION ifdef for speed.
- Drop patches:
  * o2scl-disable-slow-hdf-test.patch: No longer needed as we
    disable slow running tests by passing `-DO2SCL_FAST_TEST` to
    CXXFLAGS instead.
  * o2scl-link-quadmath.patch: fixed upstream.
- Split off tests into separate multibuild flavour to avoid main
  library builds getting bogged down by long running tests and
  also to turn off python support for the test flavour to avoid
  running python based tests. This prevents a circular dependency
  between python-o2sclpy and o2scl.
- Build with ncurses support; add BuildRequires:
  pkgconfig(ncurses).
- Switch a few *-devel BuildRequires to pkgconfig based ones.
- Account for openSUSE Leap having hdf5 < 1.12 by passing
  `-DO2SCL_HDF5_PRE_1_12` to CXXFLAGS.
- Add o2scl.rpmlintrc to mask warnings for empty files installed
  as part of doc package.
- Pass `-lgomp` to linker flags to avoid undefined symbol:
  GOMP_critical_name_end when using python o2sclpy
  (gh#awsteiner/o2scl#40).
- Update URL tag to new upstream home page.
- Disable pugixml: not for end-users (gh#awsteiner/o2scl#38).
* Thu Jul 27 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.928:
- doc package is now noarch.
- Use memory_constraints to allow at least 2GB memory per thread.
- Add _constraints.
- Drop test related patches that have been fixed upstream:
  * o2scl-eos_quark_cfl6-test-increase-tol.patch
  * o2scl-disable-test-without-destdir-support.patch
  * o2scl-failing-tests-increase-tol.patch
* Thu Aug 11 2022 Atri Bhattacharya <badshah400@gmail.com>
- Adapt CFLAGS to build with hdf5 >= 1.12.
- Add o2scl-failing-tests-increase-tol.patch: Fix some more
  failing tests by small increases of the respective tolerances.
* Thu Mar  3 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add o2scl-eos_quark_cfl6-test-increase-tol.patch: Increase the
  tolerance of a test that fails due to minor tolerance issues on
  x86_64 [gh#awsteiner/o2scl#18].
* Sun Jan 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.926:
  * Long list of changes, see
    <https://github.com/awsteiner/o2scl/releases/tag/v0.926>.
- Drop patches incorporated upstream:
  * o2scl-cpp17-legendre-conflict.patch
  * o2scl-boost-math-gamma-header.patch
  * o2scl-exp-overflow.patch
- Add o2scl-disable-test-without-destdir-support.patch: Disable
  tests that use data files installed to datadir but does not
  support DESTDIR and therefore cannot be run in a buildroot env.
- Minor specfile cleanups.
* Tue Jun  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add o2scl-cpp17-legendre-conflict.patch -- Rename function
  legendre() to legendrex() to avoid conflict with std::legendre()
  in c++17 (default in GCC 11) [gh#awsteiner/o2scl#17].
- Update URL to current upstream.
* Tue May  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add o2scl-boost-math-gamma-header.patch: Include boost header
  required for tgamma function.
- Fix an EOL encoding issue.
* Tue Nov 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.925:
  * Fixed interpolation bug and log grid bug in
    tensor_grid::rearrange_and_copy().
  * Improved acol docs everywhere. Created acol table3d
    to-tensor-grid, acol table3d to-hist-2d, acol table3d
    get-grid, acol create table-mv, acol table3d slice-hist, acol
    table3d select, acol h5-copy, acol table correl, acol
    constant, acol binary, acol docs, and acol wdocs.
  * The integration routines for semi-infinite intervals have been
    refactored to use \ref integ_iu(), \ref integ_il() and \ref
    integ_i().
  * Improved error handling and documentation in cloud_file.
  * Several updates to eos_sn, nstar_rot, eos_had_rmf,
    eos_had_rmf_hyp_ts, and ex_eos_gibbs.
  * Created new beta-equilibrium functions in some EOS classes.
  * Created new function nucmass_fit::fit_covar() to fit nuclear
    masses with a covariance matrix.
  * Reworked documentation in sphinx/breathe.
  * Fixed spacing bug in rewrap_keep_endlines().
  * Updated strings_spec(), vector_spec(), mult_vector_spec() and
    value_spec().
  * Added OpenMP support to some table functions. Updated
    table::swap().
  * Created experimental new convert_units::convert_calc()
    function and created find_constants class. Updated solar
    system constants.
  * Improvements to the vec_index class.
  * Updated the vector_acor() function. Created vectors_equal()
    and vectors_equal_tol().
  * Fixed hidden virtual function warnings.
  * Created columnify::add_spaces().
  * Worked on multiprecision support for several particle classes.
  * Cleaned up polylogs and created bessel_K_exp class.
  * Fixed HDF5 1.12-related deprecation warnings.
  * Renamed integration classes for infinite or semi-infinite
    limits.
  * Created a new experimental auto_format class.
  * Created new vt100 string functions and moved them into a new
    terminal class.
  * Added quadratic and cubic discriminants.
  * Added experimental part_pdg.
- Add o2scl-disable-slow-hdf-test.patch: Disable a slow hdf test
  that causes OBS workers to time out.
- Add o2scl-exp-overflow.patch: Fix for overflows from GSL exp.c;
  patch taken from upstream git commit [gh#awsteiner/o2scl#16].
- Drop o2scl-disable-failing-eos-test.patch: Fixed upstream.
- Pass "-DO2SCL_HDF5_PRE_1_12" to CXXFLAGS to use HDF5 1.10.x
  specific definitions.
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.924:
  * Updated second derivatives of the pressure for the particle
    clases and updated the eos_had_skyrme class to compute second
    derivatives.
  * Created a new system for OS detection to make compilation a
    bit more user-friendly. HDF5 headers have been reworked a bit
    accordingly.
  * Improved integration between acol and o2sclpy.
  * Improved the handling of aliases in acol and cli.
  * Generalized convert_units, several of the integration classes,
    a few derivative and solver classes, and several of the
    particle classes to templates to allow for other floating
    point types.
  * Improvements to the ex_mmin example and the example plots.
    Created new example ex_fermion_summ.
  * Improvements to the ode_iv_solve_grid class.
  * Improved error handling for calculator class.
  * Created functions vector_refine(), file_exists(), and
    o2isfinite().
  * Created classes inte_tanh_sinh_boost, inte_sinh_sinh_boost,
    inte_kronrod_boost, inte_exp_tanh_boost, nucmass_gen, and
    frib_mex.
  * Created a couple_threads option and an ac_coeffs() function
    for mcmc_para.
  * Creating strings_spec() for string list specifications and
    updated vector_spec() and mult_vector_spec().
  * Improved tabulate option for tov_love::calc_y().
  * Updated constants for CODATA 2018 release.
- Drop o2scl-fix-LU-tests.patch: incorporated upstream.
- Add o2scl-disable-failing-eos-test.patch -- Disable a failing
  test for eos which fails due to minor float error in the test
  file (gh#awsteiner/o2scl#10).
- Use %%license to install COPYING file.
* Wed Oct 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Add o2scl-fix-LU-tests.patch: Fix -- rather than disable --
  failing LU tests (gh#awsteiner/o2scl#9).
- Drop o2scl-disable-failing-tests.patch: No longer needed due to
  fixes from new patch o2scl-fix-LU-tests.patch; also drop
  libtool BuildRequires and do not run autoreconf before configure
  which were all required because of this patch.
* Fri Sep 13 2019 Atri Bhattacharya <badshah400@gmail.com>
- Add o2scl-disable-failing-tests.patch: Disable LU test that
  fails on x86_64 (gh#awsteiner/o2scl#9).
* Tue Apr 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.923:
  * A new function "rearrange_and_copy()" was added to the tensor
    and tensor_grid classes for several kinds of tensor
    rearrangements.
  * A new matrix_view_transpose class and a new wordexp() function
    were created.
  * The classes cloud_file, boson_rel, eos_had_skyrme,
    eos_tov_buchdahl, fermion_deriv_rel, fermion_eff,
    fermion_nonrel, fermion_rel, eos_had_rmf, hist, interpm_krige,
    and interp_krige_optim classes were improved improved. The
    particle calibration routines were improved.
  * The constants were updated for the CODATA 2014 release.
  * Several updates were made to acol. The handling of tensor and
    tensor_grid classes was improved. Vector and value
    specifications were added. The help text was reworked. The
    autocorr command was improved.
  * A new class slack_messenger was created to send messages to
    Slack.
- Drop o2scl-remove-glob_wrapper-test.patch: incorporated
  upstream.
* Tue Oct 30 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix URL (old link dead)
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 0.922:
  * In the table class, the set() function no longer automatically
    adds rows or columns. This prevents some behavior which was
    not intuitive for users.
  * Several tensor functions have been added, including
    tensor::swap_data(), tensor_out(), tensor::min(),
    tensor::max(), tensor::copy(), tensor::is_valid().
  * Slicing for tensor_grid objects has been improved.
  * Copy constructors for tensor and tensor_grid have been
    created.
  * A few long double integration classes have been added when
    higher accuracy is required.
  * The MCMC classes have been completely reworked, offering
    better support for OpenMP and MPI parallelism.
  * The acol command has been expanded and improved in several
    ways. Code for o2graph has been moved out and the
    documentation has been improved.
  * The conversion functions in convert_units now has a const
    version
  * The documentation has been improved everywhere.
  * A new nearest neighbor interpolation type has been added.
  * A seed bug in rng_gsl has been fixed.
  * HDF5 I/0 for table3d types now allows const references.
  * The cloud_file class is updated and simplified.
  * The prob_dens_func_amr class has been updated.
  * Some work has been done on heat capacity functions for
    particle objects.
  * The fermion_rel::calc_mu() and pair_mu() functions work better
    now with bad initial guesses.
  * The tov_solve, eos_tov, eos_cs2_const, and eos_had_rmf_hyp
    classes are improved.
- Drop o2scl-decrease-fit_fix-tolerances.patch: upstreamed.
- Add o2scl-remove-glob_wrapper-test.patch: Remove glob_wrapper()
  from misc_ts because it isn't platform independent; patch taken
  from upstream git (gh#awsteiner/o2scl#8).
* Tue Apr 24 2018 guillaume.gardet@opensuse.org
- Enable test only on x86_64 since all other archs do not support
  low tolerances
* Tue Mar 27 2018 badshah400@gmail.com
- Disable tests on i586 until test codes are fixed, typically
  simply by increasing tolerances (gh#awsteiner/o2scl#7).
* Tue Mar  6 2018 badshah400@gmail.com
- Add o2scl-decrease-fit_fix-tolerances.patch: Decrease the
  tolerance level on fit_fix test to prevent errors on 32-bit
  systems during make check; patch taken from upstream git
  (gh#awsteiner/o2scl#7).
* Tue Mar  6 2018 badshah400@gmail.com
- Only enable gsl2 features for openSUSE >= 1500; gsl >= 2.0 is
  not available for older openSUSE.
* Tue Feb 27 2018 badshah400@gmail.com
- Update to version 0.921:
  * New vector_autocorr() functions were created to analyze
    autocorrelations.
  * The class serach_vec now has improved thread safety.
  * Kriging classes interpm_krige_nn, interpm_krige, and
    interp_krige were created. These are still a bit experimental.
  * A new Robbins-Monro iteration root-finding class has been
    created. A class smooth_func for smoothing multivariate
    functions by averaging in a neighborhood has been created.
    These should help dealing with noisy functions.
  * All 'funct11' classes have been renamed to 'funct'.
  * New vector bin size functions have been created.
  * The 'acol' command has been reworked to handle HDF5 I/O for
    more types. It can now manipulate vectors, matrices, and
    tensors in several new ways. The interaction with o2graph in
    o2sclpy has also been improved.
  * The Markov chain Monte Carlo classes have been updated, but
    are still experimental. Similarly with the probability
    density distribution classes where new bivariate gaussian
    and AMR-like probability densities were created.
  * The internal bibliography mechanics have been improved.
  * Error handling in nucleus_rmf has been improved.
  * Updates to eos_tov_vectors, eos_had_rmf, eos_tov_vectors,
    eos_had_skyrme.
  * Created an eos_cs2_poly class and anneal_para_ts.
  * Nuclear masses were updated for the 2016 AME data set.
  * The calculation of dndT, dndmu, and dsdT for relativistic
    fermions has been improved.
  * The SFHo and SFHx EOSs were updated.
  * Several internal changes have been made to allow Ubuntu-style
    packages. The 'make check' target now works without 'make
    install'. A snapcraft snap has also been created. These are
    still in progress.
- Run tests in a check section.
- Remove bogus duplicated doc files from non-std location
  [/usr/search].
* Tue Aug 29 2017 jengelh@inai.de
- Upgrade RPM groups; combine two find calls.
* Fri Aug 25 2017 badshah400@gmail.com
- Fix package groups: shared library -> System/Libraries, devel
  package -> Productivity/Scientific/Math.
* Thu Aug 10 2017 badshah400@gmail.com
- Use boost-devel instead of libboost_headers-devel where the
  latter is not available (openSUSE < 1320).
* Tue Aug  8 2017 badshah400@gmail.com
- Initial package.
